package cn.com.qmth.examcloud.starters.face.verify.model.baidu;

import cn.com.qmth.examcloud.starters.face.verify.model.IResult;
import cn.com.qmth.examcloud.starters.face.verify.utils.JsonHelper;

/**
 * @author: QMTH
 * @since: 2019/3/25
 */
public class BaiduResponseInfo implements IResult {

    private static final long serialVersionUID = 1L;

    private Integer error_code;

    private String error_msg;

    private Long log_id;

    private BaiduResultInfo result;

    @Override
    public boolean isDetectPass() {
        //是否人脸活体检测通过 (默认推荐值：0.393241)
        if (getError_code() == 0 && result != null && result.getFace_liveness() > 0.39) {
            return true;
        }
        return false;
    }

    @Override
    public boolean isComparePass() {
        //是否人脸识别对比通过(暂未实现)
        return false;
    }

    @Override
    public Double getConfidenceValue() {
        //置信度
        if (result != null) {
            return result.getFace_liveness();
        }
        return null;
    }

    @Override
    public String getThresholdValue() {
        //置信度阈值(JSON)
        if (result != null && result.getThresholds() != null) {
            return new JsonHelper().toJson(result.getThresholds());
        }
        return null;
    }

    @Override
    public int getFaceSize() {
        //人脸数
        if (getError_code() == 0 && result != null) {
            return result.getFace_num();
        }
        return 0;
    }

    @Override
    public boolean requestOutOfLimit() {
        //请求并发是否超限(默认12个/秒)
        if (getError_code() == 18) {
            return true;//百度错误码为18
        }
        return false;
    }

    @Override
    public boolean isTokenExpired() {
        // Token默认有效期为30天
        if (getError_code() == 110 || getError_code() == 111) {
            // 已失效或过期
            return true;
        }

        // Token有效
        return false;
    }

    public Integer getError_code() {
        if (error_code == null) {
            return -1;
        }
        return error_code;
    }

    public void setError_code(Integer error_code) {
        this.error_code = error_code;
    }

    public String getError_msg() {
        return error_msg;
    }

    public void setError_msg(String error_msg) {
        this.error_msg = error_msg;
    }

    public Long getLog_id() {
        return log_id;
    }

    public void setLog_id(Long log_id) {
        this.log_id = log_id;
    }

    public BaiduResultInfo getResult() {
        return result;
    }

    public void setResult(BaiduResultInfo result) {
        this.result = result;
    }

}