package cn.com.qmth.examcloud.starters.face.verify.service;

import cn.com.qmth.examcloud.starters.face.verify.model.IResult;

import java.io.File;
import java.io.Serializable;

/**
 * @author: QMTH
 * @since: 2019/3/25
 */
public interface FaceVerifyService extends Serializable {

    /**
     * 执行百度的人脸的活体检测
     *
     * @param targetImageUrl 图片访问链接
     * @return
     */
    IResult detectFaceByBaidu(String targetImageUrl);

    /**
     * 执行百度的人脸的活体检测
     *
     * @param imageFileBytes 图片文件流
     * @return
     */
    IResult detectFaceByBaidu(byte[] imageFileBytes);

    /**
     * 执行百度的人脸的活体检测
     *
     * @param targetImageFile 图片文件
     * @return
     */
    IResult detectFaceByBaidu(File targetImageFile);

    /**
     * 执行百度的人脸的检测(可检测人脸数)
     *
     * @param targetImageFile 图片文件
     * @return
     */
    IResult detectFaceWithFaceSizeByBaidu(File targetImageFile);

    /**
     * 执行百度的人脸的检测(可检测人脸数)
     *
     * @param imageFileBytes 图片文件流
     * @return
     */
    IResult detectFaceWithFaceSizeByBaidu(byte[] imageFileBytes);

    /**
     * 执行Face++的人脸的活体检测
     *
     * @param targetImageFile 图片文件
     * @return
     */
    IResult detectFaceByFacePlus(File targetImageFile);

    /**
     * 执行Face++的人脸的活体检测
     *
     * @param imageFileBytes 文件流
     * @param imageFileName  文件名
     * @return
     */
    IResult detectFaceByFacePlus(byte[] imageFileBytes, String imageFileName);

    /**
     * 执行Face++的人脸识别对比
     *
     * @param sourceImageUrl 底照访问链接
     * @param targetImageUrl 抓拍照访问链接
     * @return
     */
    IResult compareFaceByFacePlus(String sourceImageUrl, String targetImageUrl);

    /**
     * 执行Face++的人脸识别对比
     *
     * @param sourceImageFile 底照文件
     * @param targetImageFile 抓拍照文件
     */
    IResult compareFaceByFacePlus(File sourceImageFile, File targetImageFile);

    /**
     * 执行Face++的人脸识别对比
     *
     * @param sourceImageUrl  底照访问链接
     * @param targetImageFile 抓拍照文件
     * @return
     */
    IResult compareFaceByFacePlus(String sourceImageUrl, File targetImageFile);

}